<?php

namespace Catalogo\Catalogo\Providers;

use Illuminate\Support\ServiceProvider;

class CatalogoServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'catalogo');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'catalogo');

        // Call pblish redources function
        $this->publishResources();

        include __DIR__ . '/../Http/routes.php';
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('catalogo', function ($app) {
            return $this->app->make('Catalogo\Catalogo\Catalogo');
        });

        // Bind Catalogo to repository
        $this->app->bind(
            \Catalogo\Catalogo\Interfaces\CatalogoRepositoryInterface::class,
            \Catalogo\Catalogo\Repositories\Eloquent\CatalogoRepository::class
        );

        $this->app->register(\Catalogo\Catalogo\Providers\AuthServiceProvider::class);
        $this->app->register(\Catalogo\Catalogo\Providers\EventServiceProvider::class);
        $this->app->register(\Catalogo\Catalogo\Providers\RouteServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['catalogo'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('package/catalogo.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/catalogo')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/catalogo')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');
    }
}
